@@ -1,5 +1,5 @@
 "rda.default" <-
-  function (X, Y, Z, scale = FALSE, ...) 
+    function (X, Y, Z, scale = FALSE, ...) 
 {
     ZERO <- 1e-04
     CCA <- NULL
@@ -17,7 +17,7 @@
         tmp <- sum(svd(Z, nu = 0, nv = 0)$d^2)/NR
         if (Q$rank) {
             pCCA <- list(rank = Q$rank, tot.chi = tmp, QR = Q, 
-                         Fit = Z)
+                         Fit = Z, envcentre = attr(Z.r, "scaled:center"))
             Xbar <- qr.resid(Q, Xbar)
         }
     }
@@ -52,8 +52,8 @@
             CCA$wa.eig <- CCA$wa.eig/sqrt(NR)
             CCA$wa <- sweep(CCA$wa.eig, 2, 1/sol$d[1:rank], "*")
             oo <- Q$pivot
-            if (!is.null(pCCA$rank))
-                oo <- oo[-(1:pCCA$rank)] - ncol(Z.r) 
+            if (!is.null(pCCA$rank)) 
+                oo <- oo[-(1:pCCA$rank)] - ncol(Z.r)
             oo <- oo[1:rank]
             if (length(oo) < ncol(Y.r)) 
                 CCA$alias <- colnames(Y.r)[-oo]
@@ -62,6 +62,7 @@
             CCA$rank <- rank
             CCA$tot.chi <- sum(CCA$eig)
             CCA$QR <- Q
+            CCA$envcentre <- attr(Y.r, "scaled:center")
             CCA$Xbar <- Xbar
             Xbar <- qr.resid(Q, Xbar)
         }
