@@ -1,5 +1,5 @@
 "wascores" <-
-    function (x, w, expand = FALSE) 
+function (x, w, expand = FALSE) 
 {
     x <- as.matrix(x)
     w <- as.matrix(w)
@@ -16,10 +16,13 @@
         wa.w <- colSums(w)
         x.cov <- cov.wt(x, x.w)
         wa.cov <- cov.wt(wa, wa.w)
+        x.cov$cov <- x.cov$cov * (1 - sum(x.cov$wt^2))
+        wa.cov$cov <- wa.cov$cov * (1 - sum(wa.cov$wt^2))
         mul <- sqrt(diag(x.cov$cov)/diag(wa.cov$cov))
         wa <- sweep(wa, 2, wa.cov$center, "-")
         wa <- sweep(wa, 2, mul, "*")
         wa <- sweep(wa, 2, wa.cov$center, "+")
+        attr(wa, "shrinkage") <- 1/mul^2
     }
     wa
 }
